from django_tables2 import SingleTableView
from django.views.generic.edit import UpdateView, CreateView, DeleteView
from SharixAdmin.tables import CommentsTable
from django.contrib.auth.mixins import UserPassesTestMixin
from SharixAdmin.forms import CommentsCreateForm, ServiceTypeUpdateForm
from dbsynce.models import ServiceType
from django.urls import reverse
from django.utils.translation import gettext as _

    
    
class TechCreate(UserPassesTestMixin, CreateView):
    model = ServiceType
    form_class = CommentsCreateForm
    template_name = "SharixAdmin/service_type_form.html"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context.update({
            'title': _('Техническая поддержка'),
            'object': self.object,
            "current_page": "tech_support"
        })
        return context
    
    def get_success_url(self):
        return reverse('tech_support')
    
    def test_func(self) -> bool or None:
        group_names = ('METASERVICE-ADMIN')
        if bool(self.request.user.groups.filter(name=group_names)) or self.request.user.is_superuser:
            return True
        return False
    
    
       

class TechListView(UserPassesTestMixin, SingleTableView):
    table_class = CommentsTable
    queryset = ServiceType.objects.all()
    template_name = 'SharixAdmin/tech_support.html'

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context.update({
            'title': 'Техническая поддержка',
            'object_list': context['object_list'],
            "current_page": "tech_support"
        })
        return context
    
    def testing(self, queryset, is_descending):
        queryset = queryset.annotate.order_by("-" if is_descending else "")
        return (queryset, True)

    def test_func(self) -> bool or None:
        group_names = ('METASERVICE-ADMIN')
        if bool(self.request.user.groups.filter(name=group_names)) or self.request.user:
            return True
        return False